# textual-dissect

A tool for dissecting [Textual](https://github.com/textualize/textual/) widgets,
including default CSS and more.

![screenshot](https://raw.githubusercontent.com/TomJGooding/textual-dissect/main/assets/screenshot.png)

## About

The [Textual documentation](https://textual.textualize.io/) is excellent, but
sometimes you need to dig a bit deeper. I regularly found myself having to dive
into the source code to check the default CSS for widgets.

`textual-dissect` provides quick and easy access to the default CSS and other
inner workings of Textual widgets not covered by the documentation.

## Installation

Install `textual-dissect` using pip:

```
pip install textual-dissect
```

> [!NOTE]
> It is recommended to install `textual-dissect` within your Textual project
> using pip, rather than as a standalone tool with pipx or uvx.
> This ensures that the Textual version in this tool aligns with the version
> in your current project.

## License

Licensed under the [GNU General Public License v3.0](LICENSE).
